@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getConnections(vmanage, deviceId):
     """
     Get cellular connection list from device
@@ -14,8 +11,8 @@ def getConnections(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/connection?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/connection?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getHardwareList(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getHardwareList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/hardware?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/hardware?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getModemList(vmanage, policyId):
     """
@@ -46,8 +43,8 @@ def getModemList(vmanage, policyId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/modem?policyId={policyId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/modem?policyId={policyId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getNetworkList(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getNetworkList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/network?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/network?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getProfileList(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getProfileList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/profiles?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/profiles?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRadioList(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getRadioList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/radio?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/radio?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSessionsList(vmanage, ifName, priDns, deviceId):
     """
@@ -112,8 +109,8 @@ def getSessionsList(vmanage, ifName, priDns, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/sessions?ifName={ifName}&priDns={priDns}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/sessions?ifName={ifName}&priDns={priDns}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getCellularStatusList(vmanage, deviceId):
     """
@@ -128,6 +125,6 @@ def getCellularStatusList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/cellular/status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/cellular/status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
