@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getLogs(vmanage, deviceId):
     """
     Get device crash logs from device
@@ -14,8 +11,8 @@ def getLogs(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/crashlog?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/crashlog?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getAllLogs(vmanage):
     """
@@ -29,8 +26,8 @@ def getAllLogs(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/crashlog/details"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/crashlog/details"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getInfo(vmanage, deviceId, filename):
     """
@@ -46,8 +43,8 @@ def getInfo(vmanage, deviceId, filename):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/crashlog/log?deviceId={deviceId}&filename={filename}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/crashlog/log?deviceId={deviceId}&filename={filename}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getLogsSynced(vmanage, deviceId):
     """
@@ -62,6 +59,6 @@ def getLogsSynced(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/crashlog/synced?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/crashlog/synced?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
