@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getDspActive(vmanage, deviceId):
     """
     Get DSPFarm Active DSP info from device
@@ -14,8 +11,8 @@ def getDspActive(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voice/dspActive?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voice/dspActive?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPhoneInfo(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getPhoneInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voice/phoneInfo?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voice/phoneInfo?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDSPFarmProfiles(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getDSPFarmProfiles(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voice/profiles?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voice/profiles?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSccpCcmGroups(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getSccpCcmGroups(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voice/sccpCcmGroups?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voice/sccpCcmGroups?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSccpConnections(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getSccpConnections(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voice/sccpConnections?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voice/sccpConnections?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getVoiceCalls(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getVoiceCalls(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voice/voiceCalls?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voice/voiceCalls?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getVoipCalls(vmanage, deviceId):
     """
@@ -110,8 +107,8 @@ def getVoipCalls(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voice/voipCalls?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voice/voipCalls?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getIsdnStatus(vmanage, deviceId):
     """
@@ -126,8 +123,8 @@ def getIsdnStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voiceisdninfo/isdnstatus?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voiceisdninfo/isdnstatus?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getControllerInfo(vmanage, deviceId):
     """
@@ -142,8 +139,8 @@ def getControllerInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voicet1e1controllerinfo/current15minstats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voicet1e1controllerinfo/current15minstats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getControllerStats(vmanage, deviceId):
     """
@@ -158,6 +155,6 @@ def getControllerStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/voicet1e1controllerinfo/totalstats?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/voicet1e1controllerinfo/totalstats?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
